package com.jiankangyouyi.cloud.assessment.model.entity.mongo;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.jiankangyouyi.cloud.core.util.json.serialize.QiniuKeyToUrlJsonSerialize;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.bson.types.ObjectId;
import org.springframework.data.annotation.Id;
import org.springframework.data.mongodb.core.index.CompoundIndex;
import org.springframework.data.mongodb.core.index.CompoundIndexes;
import org.springframework.data.mongodb.core.index.Indexed;
import org.springframework.data.mongodb.core.mapping.Document;
import org.springframework.format.annotation.DateTimeFormat;

import javax.validation.Valid;
import javax.validation.constraints.*;
import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * 测评配置表
 *
 * @author : yangsongbo
 */
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@CompoundIndexes(
        value = {
                @CompoundIndex(
                        name = "bizType_-1_appId_-1_beginTime_-1_endTime_-1_configStatus_-1",
                        def = "{ 'bizType': -1,'appId': -1,'beginTime': -1,'endTime': -1,'configStatus': -1}"
                )
        }
)
@Document(collection = "assessment.config")
public class AssessmentConfigDO {

    private static final long serialVersionUID = 1L;

    /**
     * 主键
     */
    @Id
    private ObjectId id;

    /**
     * 配置ID，业务主键
     */
    @Indexed(unique = true)
    private String configId;

    /**
     * 配置名称
     */
    private String configName;

    /**
     * 业务类型，见《开放平台业务类型设计.xlsx》
     */
    private String bizType;

    /**
     * 应用ID，不能为空
     */
    private String appId;

    /**
     * 有效时间-开始时间
     */
    private Date beginTime;

    /**
     * 有效时间-结束时间
     */
    private Date endTime;

    /**
     * 配置状态 {@link com.jiankangyouyi.cloud.assessment.enums.ConfigStatusEnum}
     */
    private String configStatus;

    /**
     * Logo配置，可以为空
     */
    private LogoConfig logoConfig;

    /**
     * 链接位配置
     */
    private List<LinkConfig> linkConfigs;


    /**
     * 分享配置，可以为空
     */
    private ShareConfig shareConfig;

    /**
     * 二维码配置
     */
    private QrCodeConfig qrCodeConfig;

    /**
     * 修改时间
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    private Date updateTime;
    /**
     * 修改时间
     */
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(timezone = "GMT+8", pattern = "yyyy-MM-dd HH:mm:ss")
    private Date createTime;

    public static final String FIELD_ID = "_id";
    public static final String FIELD_CONFIGID = "configId";
    public static final String FIELD_CONFIGNAME = "configName";
    public static final String FIELD_BIZTYPE = "bizType";
    public static final String FIELD_APPID = "appId";
    public static final String FIELD_BEGINTIME = "beginTime";
    public static final String FIELD_ENDTIME = "endTime";
    public static final String FIELD_CONFIGSTATUS = "configStatus";
    public static final String FIELD_LOGOCONFIG = "logoConfig";
    public static final String FIELD_LOGOCONFIG_LOGOIMAGEURLS = "logoConfig.logoImageUrls";
    public static final String FIELD_LINKCONFIGS = "linkConfigs";
    public static final String FIELD_LINKCONFIGS_LOCATION = "linkConfigs.location";
    public static final String FIELD_LINKCONFIGS_LINKS = "linkConfigs.links";
    public static final String FIELD_LINKCONFIGS_LINKS_TITLE = "linkConfigs.links.title";
    public static final String FIELD_LINKCONFIGS_LINKS_LINKIMAGEURL = "linkConfigs.links.linkImageUrl";
    public static final String FIELD_LINKCONFIGS_LINKS_LINKURL = "linkConfigs.links.linkUrl";
    public static final String FIELD_LINKCONFIGS_LINKS_BEGINTIME = "linkConfigs.links.beginTime";
    public static final String FIELD_LINKCONFIGS_LINKS_ENDTIME = "linkConfigs.links.endTime";
    public static final String FIELD_SHARECONFIG = "shareConfig";
    public static final String FIELD_SHARECONFIG_TITLE = "shareConfig.title";
    public static final String FIELD_SHARECONFIG_DESC = "shareConfig.desc";
    public static final String FIELD_SHARECONFIG_SHAREIMAGEURL = "shareConfig.shareImageUrl";
    public static final String FIELD_QRCODECONFIG = "qrCodeConfig";
    public static final String FIELD_QRCODECONFIG_QRCODEIMAGEURL = "qrCodeConfig.qrCodeImageUrl";
    public static final String FIELD_QRCODECONFIG_DESC = "qrCodeConfig.desc";
    public static final String FIELD_UPDATETIME = "updateTime";
    public static final String FIELD_CREATETIME = "createTime";


    /**
     * 测评Logo配置
     *
     * @author yangsongbo
     */
    @Data
    @Builder
    @AllArgsConstructor
    @NoArgsConstructor
    public static class LogoConfig implements Serializable {

        private static final long serialVersionUID = 1L;

        /**
         * Logo图，最多3个，不能为空
         */
        @NotEmpty(message = "请求参数logoConifg.logoImages为空")
        @JsonSerialize(using = QiniuKeyToUrlJsonSerialize.class)
        private List<String> logoImages;

    }


    /**
     * 链接位配置
     *
     * @author yangsongbo
     */
    @Data
    @Builder
    @AllArgsConstructor
    @NoArgsConstructor
    public static class LinkConfig implements Serializable {

        private static final long serialVersionUID = 1L;

        /**
         * 位置，不能为空
         */
        @NotNull(message = "参数linkConfigs.location为空")
        private Integer location;

        /**
         * 链接信息列表
         */
        @Valid
        @NotEmpty(message = "参数linkConfigs.links为空")
        @Size(max = 16, message = "参数linkConfigs.links size不合法，必须小于等于16")
        private List<Link> links;

    }

    /**
     * 广告位信息
     */
    @Data
    @Builder
    @AllArgsConstructor
    @NoArgsConstructor
    public static class Link implements Serializable {
        private static final long serialVersionUID = 1L;

        /**
         * 标题,可以为空
         */
        @Size(max = 64, message = "参数linkConfig.links.title长度不合法")
        private String title;

        /**
         * 链接图,尺寸690*280，支持png、jpg，建议大小300KB以内,不能为空
         */
        @NotBlank(message = "参数linkConfig.links.linkImage为空")
        @Size(max = 128, message = "参数linkConfig.links.linkImage长度不合法")
        @JsonSerialize(using = QiniuKeyToUrlJsonSerialize.class)
        private String linkImage;

        /**
         * 链接URL，可以为空
         */
        @Size(max = 256, message = "参数linkConfig.links.linkUrl长度不合法")
        private String linkUrl;

        /**
         * 开始时间
         */
        @JsonFormat(
                timezone = "GMT+8",
                pattern = "yyyy-MM-dd HH:mm:ss"
        )
        @NotNull(message = "参数linkConfig.links.beginTime为空")
        private Date beginTime;

        /**
         * 结束时间
         */
        @JsonFormat(
                timezone = "GMT+8",
                pattern = "yyyy-MM-dd HH:mm:ss"
        )
        @NotNull(message = "参数linkConfig.links.endTime为空")
        @Future(message = "参数linkConfig.links.endTime必须是未来的时间")
        private Date endTime;
    }


    /**
     * 分享配置
     *
     * @author yangsongbo
     */
    @Data
    @Builder
    @AllArgsConstructor
    @NoArgsConstructor
    public static class ShareConfig implements Serializable {

        private static final long serialVersionUID = 1L;

        /**
         * 分享标题,不能与分享描述同时为空
         */
        @Size(max = 64, message = "参数shareConifg.title长度不合法")
        private String title;

        /**
         * 分享描述，不能与分享标题同时为空
         */
        @Size(max = 64, message = "参数shareConifg.desc长度不合法")
        private String desc;

        /**
         * 分享图，建议300*300，不能为空
         */
        @NotBlank(message = "参数shareConifg.shareImage为空")
        @Size(max = 128, message = "参数shareConifg.shareImage长度不合法")
        @JsonSerialize(using = QiniuKeyToUrlJsonSerialize.class)
        private String shareImage;

    }


    /**
     * 二维码配置
     *
     * @author yangsongbo
     */
    @Data
    @Builder
    @AllArgsConstructor
    @NoArgsConstructor
    public static class QrCodeConfig implements Serializable {

        private static final long serialVersionUID = 1L;


        /**
         * 二维码图片，建议尺寸150 * 150，支持png、jpg，小于等于100KB
         */
        @NotBlank(message = "参数qrCodeConfig.qrCodeImage为空")
        @Size(max = 128, message = "参数qrCodeConfig.qrCodeImage长度不合法")
        @JsonSerialize(using = QiniuKeyToUrlJsonSerialize.class)
        private String qrCodeImage;

        /**
         * 描述
         */
        @Size(max = 64, message = "参数qrCodeConfig.desc长度不合法")
        private String desc;

    }

}
