package com.jiankangyouyi.cloud.assessment.model.param;

import com.fasterxml.jackson.annotation.JsonInclude;
import com.jiankangyouyi.cloud.assessment.enums.GenderEnum;
import com.jiankangyouyi.cloud.core.validator.ValidDTO;
import com.jiankangyouyi.cloud.core.validator.annotation.EnumHC;
import com.jiankangyouyi.cloud.core.validator.annotation.MaxHC;
import com.jiankangyouyi.cloud.core.validator.annotation.MinHC;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import java.math.BigDecimal;

/**
 * 体检报告参数 bizType = 012505
 *
 * @author fengxuanjun
 */
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@JsonInclude(value= JsonInclude.Include.NON_NULL)
public class AssessmentMedicalReportParams implements AssessmentParams, ValidDTO {
    private static final long serialVersionUID = 1L;


    /**
     * NOT NULL 出生日期，格式为yyyy-MM-dd,年龄（周岁）大于等于18岁，小于等于100岁
     */
    @NotBlank(message = "请求参数birthday不能为空")
    private String birthday;

    /**
     * NOT NULL 性别， 1 男 2 女
     */
    @NotBlank(message = "请求参数gender不能为空")
    @EnumHC(enumTypes = GenderEnum.class,message = "请求参数gender不合法")
    private String gender;

    /**
     * NOT NULL，身高，单位 cm,大于等于100，小于230
     */
    @NotNull(message = "请求参数height不能为空")
    @MinHC(value = 100, message = "请求参数height不在合法范围[100,230]内")
    @MaxHC(value = 230, message = "请求参数height不在合法范围[100,230]内")
    private BigDecimal height;

    /**
     * NOT NULL，单位 kg，保留1位小数，大于等于25，小于200
     */
    @NotNull(message = "请求参数heithg不能为空")
    @MinHC(value = 25, message = "请求参数weight不在合法范围[25,200]内")
    @MaxHC(value = 200, message = "请求参数weight不在合法范围[25,200]内")
    private BigDecimal weight;

    /**
     * NULL 腰围，单位 cm，大于等于50，小于200
     */
    @MinHC(value = 50, message = "请求参数waistline不在合法范围[50,200]内")
    @MaxHC(value = 200, message = "请求参数waistline不在合法范围[50,200]内")
    private Integer waistline;

    /**
     * NULL 体温，单位 ℃，[0-70]
     */
    @MinHC(value = 0, message = "请求参数temp不在合法范围[0,70]内")
    @MaxHC(value = 70, message = "请求参数temp不在合法范围[0,70]内")
    private BigDecimal temp;

    /**
     * 当前心率 单位：次/分钟 范围：[1-300]
     */
    @MinHC(value = 1, message = "请求参数hr不在合法范围[1,300]内")
    @MaxHC(value = 300, message = "请求参数hr不在合法范围[1,300]内")
    private Double hr;

//    /**
//     * 	呼吸值（呼吸频率）
//     */
//    @MinHC(value = 0, message = "请求参数brFace不在合法范围[0,70]内")
//    @MaxHC(value = 70, message = "请求参数brFace不在合法范围[0,70]内")
//    private Double brFace;

    /**
     * NULL 收缩压（高压），单位 mmHg，大于等于50，小于等于230
     */
    @MinHC(value = 50, message = "请求参数systolicPressure不在合法范围[50,230]内")
    @MaxHC(value = 230, message = "请求参数systolicPressure不在合法范围[50,230]内")
    private Integer systolicPressure;

    /**
     * NULL 舒张压（低压），单位 mmHg，大于等于30，小于等于150
     */
    @MinHC(value = 30, message = "请求参数diastolicPressure不在合法范围[30,150]内")
    @MaxHC(value = 150, message = "请求参数diastolicPressure不在合法范围[30,150]内")
    private Integer diastolicPressure;

//    /**
//     * 皮下脂肪，单位 %，[0-90]
//     */
//    @MinHC(value = 0, message = "请求参数asf不在合法范围[0,90]内")
//    @MaxHC(value = 90, message = "请求参数asf不在合法范围[0,90]内")
//    private Integer asf;

//    /**
//     * 脂肪量，单位 kg，[0-200]
//     */
//    @MinHC(value = 0, message = "请求参数tbf不在合法范围[0,200]内")
//    @MaxHC(value = 200, message = "请求参数tbf不在合法范围[0,200]内")
//    private Integer tbf;

//    /**
//     * 去脂体重，单位 kg，[0-200]
//     */
//    @MinHC(value = 0, message = "请求参数ffm不在合法范围[0,200]内")
//    @MaxHC(value = 200, message = "请求参数ffm不在合法范围[0,200]内")
//    private Integer ffm;

//    /**
//     * 肌肉率，单位 kg，[0-100]
//     */
//    @MinHC(value = 0, message = "请求参数muscleRate不在合法范围[0,100]内")
//    @MaxHC(value = 100, message = "请求参数muscleRate不在合法范围[0,100]内")
//    private Integer muscleRate;

//    /**
//     * 蛋白率，单位 kg，[0-100]
//     */
//    @MinHC(value = 0, message = "请求参数pr不在合法范围[0,100]内")
//    @MaxHC(value = 100, message = "请求参数pr不在合法范围[0,100]内")
//    private Integer pr;

    /**
     * NULL 体脂率，单位 %，大于等于0，50
     */
    @MinHC(value = 0, message = "请求参数bfr不在合法范围[0,50]内")
    @MaxHC(value = 50, message = "请求参数bfr不在合法范围[0,50]内")
    private Integer bfr;

//    /**
//     * 水分率，单位 %，[0-100]
//     */
//    @MinHC(value = 0, message = "请求参数moistureRate不在合法范围[0,100]内")
//    @MaxHC(value = 100, message = "请求参数moistureRate不在合法范围[0,100]内")
//    private Integer moistureRate;

//    /**
//     * 内脏脂肪指数，无单位，[0-100]
//     */
//    @MinHC(value = 0, message = "请求参数vfi不在合法范围[0,100]内")
//    @MaxHC(value = 100, message = "请求参数vfi不在合法范围[0,100]内")
//    private Integer vfi;

    /**
     * 血氧饱和度 单位：% 范围：[1-100]
     */
    @MinHC(value = 1, message = "请求参数bloodOxygen不在合法范围[1,100]内")
    @MaxHC(value = 100, message = "请求参数bloodOxygen不在合法范围[1,100]内")
    private Integer bloodOxygen;

    /**
     * 血细胞比容，单位 %，[0-100]
     */
    @MinHC(value = 0, message = "请求参数hct不在合法范围[0,100]内")
    @MaxHC(value = 100, message = "请求参数hct不在合法范围[0,100]内")
    private BigDecimal hct;

    /**
     * 血红蛋白，单位 g/L，[0-1500]
     */
    @MinHC(value = 0, message = "请求参数hb不在合法范围[0,1500]内")
    @MaxHC(value = 1500, message = "请求参数hb不在合法范围[0,1500]内")
    private BigDecimal hb;

    /**
     * 红细胞计数，单位 10^12/L，[0-40]
     */
    @MinHC(value = 0, message = "请求参数rbc不在合法范围[0,40]内")
    @MaxHC(value = 40, message = "请求参数rbc不在合法范围[0,40]内")
    private BigDecimal rbc;

    /**
     * 红细胞体积分布宽度，单位 %，[0-100]
     */
    @MinHC(value = 0, message = "请求参数rdwCv不在合法范围[0,100]内")
    @MaxHC(value = 100, message = "请求参数rdwCv不在合法范围[0,100]内")
    private BigDecimal rdwCv;

    /**
     * 平均红细胞血红蛋白浓度，单位 g/L，[0-2000]
     */
    @MinHC(value = 0, message = "请求参数mchc不在合法范围[0,2000]内")
    @MaxHC(value = 2000, message = "请求参数mchc不在合法范围[0,2000]内")
    private BigDecimal mchc;

    /**
     * 平均红细胞血红蛋白量，单位 pg，[0-200]
     */
    @MinHC(value = 0, message = "请求参数mch不在合法范围[0,200]内")
    @MaxHC(value = 200, message = "请求参数mch不在合法范围[0,200]内")
    private BigDecimal mch;

    /**
     * 平均红细胞容积，单位 fl，[0-500]
     */
    @MinHC(value = 0, message = "请求参数mcv不在合法范围[0,500]内")
    @MaxHC(value = 500, message = "请求参数mcv不在合法范围[0,500]内")
    private BigDecimal mcv;

    /**
     * 白细胞计数，单位 10^9/L，[0-100]
     */
    @MinHC(value = 0, message = "请求参数wbc不在合法范围[0,500]内")
    @MaxHC(value = 500, message = "请求参数wbc不在合法范围[0,500]内")
    private BigDecimal wbc;

    /**
     * 血小板计数，单位 10^9/L，[0-2000]
     */
    @MinHC(value = 0, message = "请求参数pc不在合法范围[0,2000]内")
    @MaxHC(value = 2000, message = "请求参数pc不在合法范围[0,2000]内")
    private Integer pc;

    /**
     * 血小板分布宽度，单位 10^9/L，[0-100]
     */
    @MinHC(value = 0, message = "请求参数pdw不在合法范围[0,100]内")
    @MaxHC(value = 100, message = "请求参数pdw不在合法范围[0,100]内")
    private BigDecimal pdw;

    /**
     * 淋巴细胞，单位 10^9/L，[0-40]
     */
    @MinHC(value = 0, message = "请求参数lym不在合法范围[0,40]内")
    @MaxHC(value = 40, message = "请求参数lym不在合法范围[0,40]内")
    private BigDecimal lym;

    /**
     * 淋巴细胞百分数，单位 %，[0-100]
     */
    @MinHC(value = 0, message = "请求参数ly不在合法范围[0,100]内")
    @MaxHC(value = 100, message = "请求参数ly不在合法范围[0,100]内")
    private BigDecimal ly;

    /**
     * 中性粒细胞，单位 10^9/L，[0-40]
     */
    @MinHC(value = 0, message = "请求参数neut不在合法范围[0,40]内")
    @MaxHC(value = 40, message = "请求参数neut不在合法范围[0,40]内")
    private BigDecimal neut;

    /**
     * 中性粒细胞百分数，单位 %，[0-100]
     */
    @MinHC(value = 0, message = "请求参数neur不在合法范围[0,100]内")
    @MaxHC(value = 100, message = "请求参数neur不在合法范围[0,100]内")
    private BigDecimal neur;

    /**
     * 尿红细胞，单位 个/μl ，[0-4000]
     */
    @MinHC(value = 0, message = "请求参数urineRbc不在合法范围[0,4000]内")
    @MaxHC(value = 4000, message = "请求参数urineRbc不在合法范围[0,4000]内")
    private BigDecimal urineRbc;

//    /**
//     * 尿维生素C含量，单位 10^12/L ，[0-200]
//     */
//    @MinHC(value = 0, message = "请求参数uVc不在合法范围[0,200]内")
//    @MaxHC(value = 200, message = "请求参数uVc不在合法范围[0,200]内")
//    private Integer uVc;

    /**
     * 尿蛋白肌酐比，单位 mg/g ，[0-1000]
     */
    @MinHC(value = 0, message = "请求参数pcr不在合法范围[0,1000]内")
    @MaxHC(value = 1000, message = "请求参数pcr不在合法范围[0,1000]内")
    private Integer pcr;

    /**
     * 尿比重，单位 SG ，[0-10]
     */
    @MinHC(value = 0, message = "请求参数sg不在合法范围[0,10]内")
    @MaxHC(value = 10, message = "请求参数sg不在合法范围[0,10]内")
    private BigDecimal sg;

    /**
     * 尿酸碱度，无单位，[0-14]
     */
    @MinHC(value = 0, message = "请求参数uPh不在合法范围[0,14]内")
    @MaxHC(value = 14, message = "请求参数uPh不在合法范围[0,14]内")
    private BigDecimal uPh;

    /**
     * 	尿颜色，无单位，
     * 1：淡黄色
     * 2：红色
     * 3：深黄色
     * 4：白色
     * 5：黑褐色
     * 6：蓝色
     * 7：淡绿色
     */
    private String col;

    /**
     * 尿葡萄糖，无单位，
     * -：阴性
     * +-：弱阳性
     * +：阳性
     * ++：阳性
     * +++：阳性
     * ++++：阳性
     * 说明：+都代表阳性，+号越多代表阳性越重
     */
    private String glu;

    /**
     * 尿蛋白质，无单位，
     * -：阴性
     * +-：弱阳性
     * +：阳性
     * ++：阳性
     * +++：阳性
     * ++++：阳性
     * 说明：+都代表阳性，+号越多代表阳性越重
     */
    private String pro;

    /**
     * 尿白细胞，无单位，
     * -：阴性
     * +：阳性
     * ++：阳性
     * +++：阳性
     * 说明：+都代表阳性，+号越多代表阳性越重
     */
    private String leu;

    /**
     * 尿亚硝酸盐，无单位，
     * -：阴性
     * +：阳性
     * 说明：+都代表阳性，+号越多代表阳性越重
     */
    private String nit;

    /**
     * 尿潜血，无单位，
     * -：阴性
     * +-：弱阳性
     * +：阳性
     * ++：阳性
     * +++：阳性
     * 说明：+都代表阳性，+号越多代表阳性越重
     */
    private String bld;

    /**
     * 尿酮体，无单位，
     * -：阴性
     * +：阳性
     * ++：阳性
     * +++：阳性
     * 说明：+都代表阳性，+号越多代表阳性越重
     */
    private String ket;

    /**
     * 	尿胆红素，无单位，
     * -：阴性
     * +：阳性
     * ++：阳性
     * +++：阳性
     * ++++：阳性
     * 说明：+都代表阳性，+号越多代表阳性越重
     */
    private String bil;

    /**
     * 尿胆原，无单位，
     * -：阴性
     * +-：弱阳性
     * +：阳性
     * ++：阳性
     * +++：阳性
     * ++++：阳性
     * 说明：+都代表阳性，+号越多代表阳性越重
     */
    private String uro;

    /**
     * 空腹血糖 监测方法：血浆，单位 mmol/L，[1-33]
     */
    @MinHC(value = 1, message = "请求参数fbg不在合法范围[1,33]内")
    @MaxHC(value = 33, message = "请求参数fbg不在合法范围[1,33]内")
    private BigDecimal fbg;

    /**
     * 空腹血糖 监测方法：毛细血管全血，单位 mmol/L，[1-33]
     */
    @MinHC(value = 1, message = "请求参数fbgCapillary不在合法范围[1,33]内")
    @MaxHC(value = 33, message = "请求参数fbgCapillary不在合法范围[1,33]内")
    private BigDecimal fbgCapillary;

    /**
     * NULL 餐后2小时血糖，单位 mmol/L，大于等于1，小于等于33
     */
    @MinHC(value = 1, message = "请求参数pbg不在合法范围[1,33]内")
    @MaxHC(value = 33, message = "请求参数pbg不在合法范围[1,33]内")
    private BigDecimal pbg;

    /**
     * 随机血糖，单位 mmol/L，[1-33]
     */
    @MinHC(value = 1, message = "请求参数rbg不在合法范围[1,33]内")
    @MaxHC(value = 33, message = "请求参数rbg不在合法范围[1,33]内")
    private BigDecimal rbg;

    /**
     * 	睡前血糖，单位 mmol/L，[1-33]
     */
    @MinHC(value = 1, message = "请求参数bbg不在合法范围[1,33]内")
    @MaxHC(value = 33, message = "请求参数bbg不在合法范围[1,33]内")
    private BigDecimal bbg;

    /**
     * 糖化血红蛋白，单位 mmol/L，[1-20]
     */
    @MinHC(value = 1, message = "请求参数ghb不在合法范围[1,20]内")
    @MaxHC(value = 20, message = "请求参数ghb不在合法范围[1,20]内")
    private BigDecimal ghb;

    /**
     * NULL 总胆固醇，单位 mmol/L，大于等于0.01，小于等于50
     */
    @MinHC(value = 0.01, message = "请求参数tc不在合法范围[0.01,50]内")
    @MaxHC(value = 50, message = "请求参数tc不在合法范围[0.01,50]内")
    private BigDecimal tc;

    /**
     * NULL 甘油三酯，单位 mmol/L，大于等于0.01，小于等于50
     */
    @MinHC(value = 0.01, message = "请求参数tg不在合法范围[0.01,50]内")
    @MaxHC(value = 50, message = "请求参数tg不在合法范围[0.01,50]内")
    private BigDecimal tg;

    /**
     * NULL 高密度脂蛋白胆固醇，单位 mmol/L，大于等于0.01，小于等于10
     */
    @MinHC(value = 0.01, message = "请求参数hdlc不在合法范围[0.01,10]内")
    @MaxHC(value =10, message = "请求参数hdlc不在合法范围[0.01,10]内")
    private BigDecimal hdlc;

    /**
     * NULL 低密度脂蛋白胆固醇，单位 mmol/L，大于等于0.01，小于等于20
     */
    @MinHC(value = 0.01, message = "请求参数ldlc不在合法范围[0.01,20]内")
    @MaxHC(value =20, message = "请求参数ldlc不在合法范围[0.01,20]内")
    private BigDecimal ldlc;

    /**
     * NULL 非高密度脂蛋白胆固醇，单位 mmol/L，大于等于0，小于等于20
     */
    @MinHC(value = 0.01, message = "请求参数mdlc不在合法范围[0.01,20]内")
    @MaxHC(value =20, message = "请求参数mdlc不在合法范围[0.01,20]内")
    private BigDecimal mdlc;

    /**
     * NULL γ-谷氨酰转移酶值，单位 U/L，大于等于5，小于等于300
     */
    @MinHC(value = 5, message = "请求参数yggt不在合法范围[5,300]内")
    @MaxHC(value =300, message = "请求参数yggt不在合法范围[5,300]内")
    private Integer yggt;

    /**
     * 碱性磷酸酶，单位 U/L，[0-500]
     */
    @MinHC(value = 5, message = "请求参数alp不在合法范围[5,500]内")
    @MaxHC(value =500, message = "请求参数alp不在合法范围[5,500]内")
    private Integer alp;

    /**
     * 丙氨酸氨基转移酶，单位 U/L，[0-300]
     */
    @MinHC(value = 0, message = "请求参数alt不在合法范围[0,300]内")
    @MaxHC(value =300, message = "请求参数alt不在合法范围[0,300]内")
    private Integer alt;

    /**
     * 天门冬氨酸氨基转移酶，单位 U/L，[0-300]
     */
    @MinHC(value = 0, message = "请求参数ast不在合法范围[0,300]内")
    @MaxHC(value =300, message = "请求参数ast不在合法范围[0,300]内")
    private Integer ast;

    /**
     * 	白蛋白，单位 g/L，[0-300]
     */
    @MinHC(value = 0, message = "请求参数alb不在合法范围[0,300]内")
    @MaxHC(value =300, message = "请求参数alb不在合法范围[0,300]内")
    private BigDecimal alb;

    /**
     * 球蛋白，单位 g/L，[0-300]
     */
    @MinHC(value = 0, message = "请求参数glb不在合法范围[0,300]内")
    @MaxHC(value =300, message = "请求参数glb不在合法范围[0,300]内")
    private BigDecimal glb;

    /**
     * 总蛋白，单位 g/L，[0-500]
     */
    @MinHC(value = 0, message = "请求参数tp不在合法范围[0,500]内")
    @MaxHC(value =500, message = "请求参数tp不在合法范围[0,500]内")
    private BigDecimal tp;

    /**
     * 白蛋白/球蛋白，无单位 ，[0-25]
     */
    @MinHC(value = 0, message = "请求参数albGlbRatio不在合法范围[0,25]内")
    @MaxHC(value =25, message = "请求参数albGlbRatio不在合法范围[0,25]内")
    private BigDecimal albGlbRatio;

    /**
     * 结合胆红素，单位 μmol/L，[0-70]
     */
    @MinHC(value = 0, message = "请求参数cb不在合法范围[0,70]内")
    @MaxHC(value =70, message = "请求参数cb不在合法范围[0,70]内")
    private BigDecimal cb;

    /**
     * 非结合胆红素，单位 μmol/L，[0-100]
     */
    @MinHC(value = 0, message = "请求参数ucb不在合法范围[0,100]内")
    @MaxHC(value =100, message = "请求参数ucb不在合法范围[0,100]内")
    private BigDecimal ucb;

    /**
     * 总胆红素，单位 μmol/L，[0-200]
     */
    @MinHC(value = 0, message = "请求参数stb不在合法范围[0,200]内")
    @MaxHC(value =200, message = "请求参数stb不在合法范围[0,200]内")
    private BigDecimal stb;

    /**
     * 胃泌素－17，单位 pmol／L，[0-150]
     */
    @MinHC(value = 0, message = "请求参数g17不在合法范围[0,150]内")
    @MaxHC(value =150, message = "请求参数g17不在合法范围[0,150]内")
    private BigDecimal g17;

    /**
     * 胃蛋白酶原Ⅰ，单位 μg／L，[0-1500]
     */
    @MinHC(value = 0, message = "请求参数pg1不在合法范围[0,1500]内")
    @MaxHC(value =1500, message = "请求参数pg1不在合法范围[0,1500]内")
    private BigDecimal pg1;

    /**
     * 胃蛋白酶原ⅠⅠ，单位 μg／L，[0-150]
     */
    @MinHC(value = 0, message = "请求参数pg2不在合法范围[0,150]内")
    @MaxHC(value =150, message = "请求参数pg2不在合法范围[0,150]内")
    private BigDecimal pg2;

    /**
     * 胃蛋白酶原比值，无单位，[0-70]
     */
    @MinHC(value = 0, message = "请求参数pgr不在合法范围[0,70]内")
    @MaxHC(value =70, message = "请求参数pgr不在合法范围[0,70]内")
    private BigDecimal pgr;

    /**
     * NULL 血尿酸，单位 μmol/L，大于等于150，小于1000
     */
    @MinHC(value = 150, message = "请求参数ua不在合法范围[150,1000]内")
    @MaxHC(value =1000, message = "请求参数ua不在合法范围[150,1000]内")
    private Integer ua;

    /**
     * 血清总钙，单位 mmol/L，[0-25]
     */
    @MinHC(value = 0, message = "请求参数serumCa不在合法范围[0,25]内")
    @MaxHC(value =25, message = "请求参数serumCa不在合法范围[0,25]内")
    private BigDecimal serumCa;

    /**
     * 血清铜，单位 μmol/L，[0-200]
     */
    @MinHC(value = 0, message = "请求参数serumCu不在合法范围[0,200]内")
    @MaxHC(value =200, message = "请求参数serumCu不在合法范围[0,200]内")
    private BigDecimal serumCu;

    /**
     * 血清铁，单位 μmol/L，[0-300]
     */
    @MinHC(value = 0, message = "请求参数serumFe不在合法范围[0,300]内")
    @MaxHC(value =300, message = "请求参数serumFe不在合法范围[0,300]内")
    private BigDecimal serumFe;

    /**
     * 血清锌，单位 μmol/L，[0-200]
     */
    @MinHC(value = 0, message = "请求参数serumZn不在合法范围[0,200]内")
    @MaxHC(value =200, message = "请求参数serumZn不在合法范围[0,200]内")
    private BigDecimal serumZn;

    /**
     * 血清镁，单位 μmol/L，[0-20]
     */
    @MinHC(value = 0, message = "请求参数serumMg不在合法范围[0,20]内")
    @MaxHC(value =20, message = "请求参数serumMg不在合法范围[0,20]内")
    private BigDecimal serumMg;

    /**
     * NULL 骨密度T值，大于等于-6，小于等于3
     */
    @MinHC(value = -6, message = "请求参数bmdTscore不在合法范围[-6,3]内")
    @MaxHC(value = 3, message = "请求参数bmdTscore不在合法范围[-6,3]内")
    private BigDecimal bmdTscore;

    /**
     * NULL 肝内脂肪含量， 单位：%，大于等于1，小于等于50
     */
    @MinHC(value = 1,message = "请求参数liverFatContent不在合法范围[1,50]内")
    @MaxHC(value = 50,message = "请求参数liverFatContent不在合法范围[1,50]内")
    private BigDecimal liverFatContent;

//    /**
//     * 尿中尿酸， 单位：mmol/24h，[0-60]
//     */
//    @MinHC(value = 0, message = "请求参数uua不在合法范围[0,60]内")
//    @MaxHC(value = 60, message = "请求参数uua不在合法范围[1,60]内")
//    private BigDecimal uua;


}
